@@ -9,7 +9,6 @@ mod bookmark_start;
 mod br;
 mod character_spacing;
 mod color;
-mod run_style;
 mod comment;
 mod comment_extended;
 mod comment_range_end;
@@ -68,6 +67,7 @@ mod run;
 mod run_fonts;
 mod run_property;
 mod run_property_default;
+mod run_style;
 mod section;
 mod section_property;
 mod shading;
@@ -98,6 +98,7 @@ mod table_style;
 mod table_width;
 mod text;
 mod text_border;
+mod text_box;
 mod text_box_content;
 mod text_direction;
 mod underline;
@@ -137,7 +138,6 @@ pub use doc_var::*;
 pub use drawing::*;
 pub use fld_char::*;
 pub use font::*;
-pub use run_style::*;
 pub use font_scheme::*;
 pub use footer_reference::*;
 pub use grid_span::*;
@@ -180,6 +180,7 @@ pub use run::*;
 pub use run_fonts::*;
 pub use run_property::*;
 pub use run_property_default::*;
+pub use run_style::*;
 pub use section::*;
 pub use section_property::*;
 pub use shading::*;
@@ -210,6 +211,7 @@ pub use table_style::*;
 pub use table_width::*;
 pub use text::*;
 pub use text_border::*;
+pub use text_box::*;
 pub use text_box_content::*;
 pub use text_direction::*;
 pub use underline::*;
