@@ -16,7 +16,7 @@ pub struct XMLDocx {
     pub settings: Vec<u8>,
     pub font_table: Vec<u8>,
     pub numberings: Vec<u8>,
-    pub media: Vec<(usize, Vec<u8>)>,
+    pub media: Vec<(String, Vec<u8>)>,
     pub headers: Vec<Vec<u8>>,
     pub footers: Vec<Vec<u8>>,
     pub comments_extended: Vec<u8>,
