@@ -3,6 +3,7 @@ pub mod border_position;
 pub mod border_type;
 pub mod break_type;
 pub mod doc_grid_type;
+pub mod drawing_position;
 pub mod emu;
 pub mod errors;
 pub mod field_char_type;
@@ -12,6 +13,7 @@ pub mod level_suffix_type;
 pub mod line_spacing_type;
 pub mod page_margin;
 pub mod page_orientation_type;
+pub mod relative_from_type;
 pub mod section_type;
 pub mod shd_type;
 pub mod special_indent_type;
@@ -31,6 +33,7 @@ pub use border_position::*;
 pub use border_type::*;
 pub use break_type::*;
 pub use doc_grid_type::*;
+pub use drawing_position::*;
 pub use emu::*;
 pub use errors::*;
 pub use field_char_type::*;
@@ -40,6 +43,7 @@ pub use level_suffix_type::*;
 pub use line_spacing_type::*;
 pub use page_margin::*;
 pub use page_orientation_type::*;
+pub use relative_from_type::*;
 pub use section_type::*;
 pub use shd_type::*;
 pub use special_indent_type::*;
