@@ -7,8 +7,9 @@ use std::str::FromStr;
 
 #[wasm_bindgen]
 #[derive(Copy, Clone, Debug, PartialEq, Serialize)]
+#[serde(rename_all = "camelCase")]
 pub enum WidthType {
-    DXA,
+    Dxa,
     Auto,
     Pct,
     Nil,
@@ -18,7 +19,7 @@ pub enum WidthType {
 impl fmt::Display for WidthType {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match *self {
-            WidthType::DXA => write!(f, "dxa"),
+            WidthType::Dxa => write!(f, "dxa"),
             WidthType::Auto => write!(f, "auto"),
             WidthType::Pct => write!(f, "pct"),
             WidthType::Nil => write!(f, "nil"),
@@ -30,11 +31,12 @@ impl fmt::Display for WidthType {
 impl FromStr for WidthType {
     type Err = errors::TypeError;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
+        // https://github.com/bokuweb/docx-rs/issues/451
         match s {
-            "dxa" => Ok(WidthType::DXA),
-            "auto" => Ok(WidthType::Auto),
-            "pct" => Ok(WidthType::Pct),
-            "nil" => Ok(WidthType::Nil),
+            "DXA" | "dxa" => Ok(WidthType::Dxa),
+            "Auto" | "auto" => Ok(WidthType::Auto),
+            "Pct" | "pct" => Ok(WidthType::Pct),
+            "Nil" | "nil" => Ok(WidthType::Nil),
             _ => Ok(WidthType::Unsupported),
         }
     }
